@@ -280,7 +280,10 @@ class SchemaOrg:
             and isinstance(instructions, list)
             and isinstance(instructions[0], list)
         ):
-            instructions = list(chain(*instructions))  # flatten
+            if instructions and all(isinstance(item, list) for item in instructions):
+                instructions = list(
+                    chain(*instructions)
+                )  # flatten, only if all items are list
 
         if isinstance(instructions, dict):
             instructions = instructions.get("itemListElement")
