@@ -1,5 +1,5 @@
-# mypy: disallow_untyped_defs=False
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 
 
 class CookEatShare(AbstractScraper):
@@ -7,5 +7,8 @@ class CookEatShare(AbstractScraper):
     def host(cls):
         return "cookeatshare.com"
 
+    def site_name(self):
+        raise StaticValueException(return_value="CookEatShare Cookbook")
+
     def total_time(self):
         return None
