@@ -1,5 +1,4 @@
 from ._abstract import AbstractScraper
-from ._grouping_utils import group_ingredients
 from ._utils import get_equipment
 
 
@@ -14,14 +13,6 @@ class KrollsKorner(AbstractScraper):
         )
         return author_tag.get_text(strip=True)
 
-    def ingredient_groups(self):
-        return group_ingredients(
-            self.ingredients(),
-            self.soup,
-            ".wprm-recipe-ingredient-group h4",
-            ".wprm-recipe-ingredient",
-        )
-
     def equipment(self):
         equipment_container = self.soup.select_one(".wprm-recipe-equipment-container")
         if not equipment_container:
