@@ -1,7 +1,7 @@
-# mypy: disallow_untyped_defs=False
 from recipe_scrapers._grouping_utils import group_ingredients
 
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 
 
 class Matprat(AbstractScraper):
@@ -9,6 +9,9 @@ class Matprat(AbstractScraper):
     def host(cls):
         return "matprat.no"
 
+    def site_name(self):
+        raise StaticValueException(return_value="MatPrat")
+
     def ingredient_groups(self):
         return group_ingredients(
             self.ingredients(),
