@@ -12,7 +12,7 @@ class Mindmegette(AbstractScraper):
 
     def total_time(self):
         item_sibling = self.soup.find("span", {"class": "spriteTime"})
-        time = item_sibling.find_next().get_text()
+        time = item_sibling.find_next(name=True).get_text()
 
         return get_minutes(time)
 
@@ -56,6 +56,6 @@ class Mindmegette(AbstractScraper):
 
     def yields(self):
         item_sibling = self.soup.find("span", {"class": "spritePortion"})
-        portion = item_sibling.find_next().get_text()
+        portion = item_sibling.find_next(name=True).get_text()
 
         return get_yields(portion)
