@@ -1,4 +1,5 @@
 from ._abstract import AbstractScraper
+from ._grouping_utils import group_ingredients
 from ._utils import normalize_string
 
 
@@ -27,3 +28,11 @@ class TheHappyFoodie(AbstractScraper):
             )
 
         return [normalize_string(f"{amount} {name}") for amount, name in ingredients]
+
+    def ingredient_groups(self):
+        return group_ingredients(
+            self.ingredients(),
+            self.soup,
+            ".heading th",
+            ".hf-ingredients__single-group tr:not(.heading, .spacer)",
+        )
