@@ -1,5 +1,4 @@
 from ._abstract import AbstractScraper
-from ._grouping_utils import group_ingredients
 from ._utils import get_equipment
 
 
@@ -8,14 +7,6 @@ class ThePlantBasedSchool(AbstractScraper):
     def host(cls):
         return "theplantbasedschool.com"
 
-    def ingredient_groups(self):
-        return group_ingredients(
-            self.ingredients(),
-            self.soup,
-            ".wprm-recipe-ingredient-group h4",
-            ".wprm-recipe-ingredient",
-        )
-
     def equipment(self):
         equipment_items = [
             item.get_text()
