@@ -1,6 +1,5 @@
-# mypy: allow-untyped-defs
-
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 
 
 class Vegetarbloggen(AbstractScraper):
@@ -8,5 +7,8 @@ class Vegetarbloggen(AbstractScraper):
     def host(cls):
         return "vegetarbloggen.no"
 
+    def site_name(self):
+        raise StaticValueException(return_value="Vegetarbloggen")
+
     def instructions(self):
         return self.schema.instructions().strip()
